Crate aleo_std_storage

Crate aleo_std_storage 

Enums

StorageMode
An enum to define the operating mode of the Aleo node.

Functions

aleo_dir
Returns the directory for accessing resources from Aleo storage. The expected directory path to be returned is ~/.aleo/.
aleo_ledger_dir
Returns the directory for accessing the ledger files from Aleo storage.