Enums
- Storage
Mode - An enum to define the operating mode of the Aleo node.
Functions
- aleo_
dir - Returns the directory for accessing resources from Aleo storage.
The expected directory path to be returned is
~/.aleo/. - aleo_
ledger_ dir - Returns the directory for accessing the ledger files from Aleo storage.